@@ -2,20 +2,20 @@ from django.http import HttpResponse
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
-from utkik.decorators import requires_ajax, http_methods, remove_request
+from utkik.decorators import http_methods
 
 
 class ViewException(Exception):
     pass
 
 
-class Context(object):
+class ContextData(object):
     """This will contain attributes for context. All the attributes are later
-    collected by Context().__dict__.
+    collected by ContextData().__dict__.
     """
 
 
-class BaseView(object):
+class View(object):
     """A minimalist View base class.
 
     Goals
@@ -34,13 +34,12 @@ class BaseView(object):
     """
 
     methods = ['GET', 'POST'] # allowed HTTP methods
-    requires_ajax = False # force ajax
-    decorators = [] # a list of decorators applied in reverse order
+    decorators = [] # a list of decorators
     template = None # template to render to
 
     def __init__(self):
-        """All we do here is to instantiate the Context class"""
-        self.c = Context() # c is for context
+        """All we do here is to instantiate the ContextData class"""
+        self.c = ContextData() # c is for context
         self.request = None
 
     def dispatch(self, request, *args, **kwargs):
@@ -49,25 +48,28 @@ class BaseView(object):
         call to the view.
         """
         self.request = request
-        return self.decorate(self.get_response)(request, *args, **kwargs)
+        return self._decorate(self.get_response)(request, *args, **kwargs)
 
-    def decorate(self, f):
-        """Decorate function f with decorators from ``self.decorators`` and
-        decorators based on ``self.requires_ajax`` and ``self.methods``.
+    def _decorate(self, f):
+        """This is meant to decorate ``self.get_response`` with
+        ``self.decorators`` much like you would decorate a view function (if you
+        remember that era). There is one decorator automatically added here and
+        that is the ``http_methods`` computed decorator that uses
+        ``self.methods`` attribute and avalable handlers to define what methods
+        are allowed.
         """
-        f = remove_request(f) # remove request arg. for get_response method
         for d in reversed(self.decorators):
             f = d(f)
-        if self.requires_ajax:
-            f = requires_ajax(f)
         methods = [m for m in self.methods if hasattr(self, m.lower())]
         return http_methods(*methods)(f)
 
-    def get_response(self, *args, **kwargs):
+    def get_response(self, request, *args, **kwargs):
         """Returns the response from a successful request to the view. In it's
-        default implementation it will direct to a suitable handler method
-        based on the HTTP method call. If this handler does not return a
-        response, we will simply call and return ``self.render``.
+        default implementation it will direct to a suitable handler method based
+        on the HTTP method call. If this handler does not return a response, we
+        will simply call and return ``self.render``. Request is just passed in
+        here for decorator compatibilty reasons, don't use it, don't get
+        confused by it, just use ``self.request``.
         """
         return self.get_handler()(*args, **kwargs) or self.render()
 
@@ -83,14 +85,15 @@ class BaseView(object):
         """
         return self.c.__dict__
 
-    def render(self):
+    def render(self, template=None):
         """
-        Renders ``self.get_context()`` to ``self.template``. This is called from
-        ``self.get_response`` if the handler does not return a response.
+        Renders ``self.get_context()`` to ``self.template`` or a template
+        argument. This is called from ``self.get_response`` if the handler does
+        not return a response.
         """
-        if not self.template:
-            raise ViewException(
-                _('%s does not define a template to render to.') % self)
+        template = template or self.template
+        if not template:
+            raise ViewException(_('Missing template to render to.'))
         return render_to_response(
-            self.template, self.get_context(), RequestContext(self.request))
+            template, self.get_context(), RequestContext(self.request))
 
